(function($) {
    'use strict';

    $(document).ready(function() {
        // Tab functionality
        $('.nav-tab').on('click', function(e) {
            e.preventDefault();
            
            // Update tabs
            $('.nav-tab').removeClass('nav-tab-active');
            $(this).addClass('nav-tab-active');
            
            // Update content
            const targetId = $(this).attr('href');
            $('.tab-content').removeClass('active');
            $(targetId).addClass('active');
        });

        // API key validation
        $('#ai_chatbot_api_key').on('change', function() {
            const apiKey = $(this).val();
            
            $.ajax({
                url: aiChatbotAdmin.ajaxurl,
                type: 'POST',
                data: {
                    action: 'validate_api_key',
                    nonce: aiChatbotAdmin.nonce,
                    api_key: apiKey
                },
                success: function(response) {
                    if (response.success) {
                        location.reload();
                    } else {
                        alert('Invalid API key. Please check and try again.');
                    }
                }
            });
        });

        // Initialize WordPress color picker
        if ($.fn.wpColorPicker) {
            $('.color-picker').wpColorPicker({
                defaultColor: '#007bff',
                change: function(event, ui) {
                    // Optional: Add any custom handling when color changes
                }
            });
        }

        // Show/hide shortcode info based on display mode selection
        $('input[name="ai_chatbot_display_mode"]').on('change', function() {
            const shortcodeInfo = $('.shortcode-info');
            if ($(this).val() === 'shortcode') {
                shortcodeInfo.slideDown();
            } else {
                shortcodeInfo.slideUp();
            }
        });

        // Show shortcode info on page load if shortcode is selected
        if ($('input[name="ai_chatbot_display_mode"]:checked').val() === 'shortcode') {
            $('.shortcode-info').show();
        }

        // View conversation
        $('.view-conversation').click(function(e) {
            e.preventDefault();
            const conversationId = $(this).data('id');
            
            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'get_conversation_messages',
                    conversation_id: conversationId,
                    nonce: aiChatbotAdmin.nonce
                },
                success: function(response) {
                    if (response.success) {
                        let messagesHtml = '';
                        response.data.forEach(function(message) {
                            const role = message.role === 'user' ? 'user' : 'assistant';
                            const time = new Date(message.created_at).toLocaleString();
                            messagesHtml += `
                                <div class="message ${role}">
                                    <div class="message-content">${message.content}</div>
                                    <div class="message-meta">
                                        ${time} - Cost: $${message.cost}
                                    </div>
                                </div>
                            `;
                        });
                        $('.conversation-messages').html(messagesHtml);
                        $('#conversation-modal').show();
                    }
                }
            });
        });

        // Close modal
        $('.close').click(function() {
            $('#conversation-modal').hide();
        });

        // Delete conversation
        $('.delete-conversation').click(function() {
            if (confirm('Are you sure you want to delete this conversation?')) {
                const conversationId = $(this).data('id');
                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'delete_conversation',
                        conversation_id: conversationId,
                        nonce: aiChatbotAdmin.nonce
                    },
                    success: function(response) {
                        if (response.success) {
                            location.reload();
                        }
                    }
                });
            }
        });

        // Add after existing document ready function
        if (wp.media) {
            let mediaUploader;
            
            $('#upload_icon_button').on('click', function(e) {
                e.preventDefault();
                
                if (mediaUploader) {
                    mediaUploader.open();
                    return;
                }
                
                mediaUploader = wp.media({
                    title: 'Choose Chat Icon',
                    button: {
                        text: 'Use this icon'
                    },
                    multiple: false
                });
                
                mediaUploader.on('select', function() {
                    const attachment = mediaUploader.state().get('selection').first().toJSON();
                    $('#custom_icon_url').val(attachment.url);
                    $('#icon_preview').html(`<img src="${attachment.url}" style="max-width: 60px;">`);
                });
                
                mediaUploader.open();
            });
            
            $('#ai_chatbot_appearance_icon_type').on('change', function() {
                if ($(this).val() === 'custom') {
                    $('#custom-icon-upload').show();
                } else {
                    $('#custom-icon-upload').hide();
                }
            });
        }
    });
})(jQuery);