<?php
if (!defined('WPINC')) {
    die;
}
?>

<div class="wrap">
    <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
    
    <nav class="nav-tab-wrapper">
        <a href="#api-settings" class="nav-tab nav-tab-active">API Settings</a>
        <a href="#general-settings" class="nav-tab">General Settings</a>
        <a href="#display-settings" class="nav-tab">Display Settings</a>
        <a href="#appearance-settings" class="nav-tab">Appearance Settings</a>
    </nav>

    <form method="post" action="options.php">
        <?php
        settings_fields('ai_chatbot_settings');
        do_settings_sections('ai_chatbot_settings');
        
        $appearance = get_option('ai_chatbot_appearance', array(
            'chat_color' => '#007bff',
            'messages_color' => '#ffffff',
            'messages_border_radius' => '10',
            'chat_box_border_radius' => '15',
            'custom_css' => '',
            'icon_type' => 'default',
            'icon_size' => '60',
            'chat_box_width' => '350',
            'chat_box_height' => '500',
            'user_message_font_size' => '14',
            'bot_message_font_size' => '14',
            'header_font_size' => '16',
            'bot_message_bg' => '#f1f1f1'
        ));
        ?>
        
        <div id="api-settings" class="tab-content active">
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_api_key">API Key</label>
                    </th>
                    <td>
                        <input type="text" 
                               id="ai_chatbot_api_key" 
                               name="ai_chatbot_api_key" 
                               value="<?php echo esc_attr(get_option('ai_chatbot_api_key')); ?>" 
                               class="regular-text">
                        <br>
                        <a href="https://quickworkspace.ai/app/myapikey" 
                           target="_blank" 
                           class="button button-secondary" 
                           style="margin-top: 5px;">
                            Get API Key
                        </a>
                    </td>
                </tr>
            </table>
        </div>

        <div id="general-settings" class="tab-content">
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_chat_title">Chat Title</label>
                    </th>
                    <td>
                        <input type="text" 
                               id="ai_chatbot_chat_title" 
                               name="ai_chatbot_chat_title" 
                               value="<?php echo esc_attr(get_option('ai_chatbot_chat_title', 'Chat Support')); ?>" 
                               class="regular-text">
                    </td>
                </tr>
                
                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_instructions">Chat Instructions</label>
                    </th>
                    <td>
                        <textarea id="ai_chatbot_instructions" 
                                  name="ai_chatbot_instructions" 
                                  rows="5" 
                                  class="large-text"><?php echo esc_textarea(get_option('ai_chatbot_instructions')); ?></textarea>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_selected_model">AI Model</label>
                    </th>
                    <td>
                        <select id="ai_chatbot_selected_model" name="ai_chatbot_selected_model">
                            <?php
                            $selected_model = get_option('ai_chatbot_selected_model');
                            $available_models = get_option('ai_chatbot_available_models', array());
                            
                            if (empty($available_models)) {
                                echo '<option value="">Please validate your API key first</option>';
                            } else {
                                foreach ($available_models as $model) {
                                    printf(
                                        '<option value="%s" %s>%s</option>',
                                        esc_attr($model),
                                        selected($selected_model, $model, false),
                                        esc_html($model)
                                    );
                                }
                            }
                            ?>
                        </select>
                    </td>
                </tr>
            </table>
        </div>

        <div id="display-settings" class="tab-content">
            <table class="form-table">
                <tr>
                    <th scope="row">Display Mode</th>
                    <td>
                        <fieldset>
                            <label>
                                <input type="radio" 
                                       name="ai_chatbot_display_mode" 
                                       value="entire_site" 
                                       <?php checked('entire_site', get_option('ai_chatbot_display_mode', 'entire_site')); ?>>
                                Entire Website
                            </label>
                            <br>
                            <label>
                                <input type="radio" 
                                       name="ai_chatbot_display_mode" 
                                       value="shortcode" 
                                       <?php checked('shortcode', get_option('ai_chatbot_display_mode')); ?>>
                                Shortcode
                            </label>
                            <p class="description shortcode-info" style="display: none;">
                                Use this shortcode to display the chatbot: <code>[ai_business_chatbot]</code>
                            </p>
                        </fieldset>
                    </td>
                </tr>
            </table>
        </div>

        <div id="appearance-settings" class="tab-content">
            <table class="form-table">
                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[chat_color]">Chat Color</label>
                    </th>
                    <td>
                        <input type="text" 
                               id="ai_chatbot_appearance_chat_color" 
                               name="ai_chatbot_appearance[chat_color]" 
                               value="<?php echo esc_attr($appearance['chat_color']); ?>"
                               class="color-picker">
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[messages_color]">Messages Color</label>
                    </th>
                    <td>
                        <input type="text" 
                               id="ai_chatbot_appearance_messages_color" 
                               name="ai_chatbot_appearance[messages_color]" 
                               value="<?php echo esc_attr($appearance['messages_color']); ?>"
                               class="color-picker">
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[messages_border_radius]">Messages Border Radius</label>
                    </th>
                    <td>
                        <input type="number" 
                               id="ai_chatbot_appearance_messages_border_radius" 
                               name="ai_chatbot_appearance[messages_border_radius]" 
                               value="<?php echo esc_attr($appearance['messages_border_radius']); ?>"
                               min="0"
                               max="50">
                        <span class="description">px</span>
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[chat_box_border_radius]">Chat Box Border Radius</label>
                    </th>
                    <td>
                        <input type="number" 
                               id="ai_chatbot_appearance_chat_box_border_radius" 
                               name="ai_chatbot_appearance[chat_box_border_radius]" 
                               value="<?php echo esc_attr($appearance['chat_box_border_radius']); ?>"
                               min="0"
                               max="50">
                        <span class="description">px</span>
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[custom_css]">Custom CSS</label>
                    </th>
                    <td>
                        <textarea id="ai_chatbot_appearance_custom_css" 
                                  name="ai_chatbot_appearance[custom_css]" 
                                  rows="5" 
                                  class="large-text code"><?php echo esc_textarea($appearance['custom_css']); ?></textarea>
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[icon_type]">Chat Icon</label>
                    </th>
                    <td>
                        <select id="ai_chatbot_appearance_icon_type" name="ai_chatbot_appearance[icon_type]">
                            <option value="default" <?php selected($appearance['icon_type'], 'default'); ?>>Default Icon</option>
                            <option value="custom" <?php selected($appearance['icon_type'], 'custom'); ?>>Custom Image</option>
                        </select>
                        <div id="custom-icon-upload" style="margin-top: 10px; <?php echo $appearance['icon_type'] === 'custom' ? '' : 'display: none;'; ?>">
                            <input type="hidden" name="ai_chatbot_appearance[custom_icon]" id="custom_icon_url" value="<?php echo esc_attr($appearance['custom_icon'] ?? ''); ?>">
                            <button type="button" class="button" id="upload_icon_button">Upload Icon</button>
                            <div id="icon_preview" style="margin-top: 10px;">
                                <?php if (!empty($appearance['custom_icon'])): ?>
                                    <img src="<?php echo esc_url($appearance['custom_icon']); ?>" style="max-width: 60px;">
                                <?php endif; ?>
                            </div>
                        </div>
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[icon_size]">Icon Size</label>
                    </th>
                    <td>
                        <input type="number" 
                               id="ai_chatbot_appearance_icon_size" 
                               name="ai_chatbot_appearance[icon_size]" 
                               value="<?php echo esc_attr($appearance['icon_size'] ?? '60'); ?>"
                               min="40"
                               max="100">
                        <span class="description">px</span>
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[chat_box_width]">Chat Box Width</label>
                    </th>
                    <td>
                        <input type="number" 
                               id="ai_chatbot_appearance_chat_box_width" 
                               name="ai_chatbot_appearance[chat_box_width]" 
                               value="<?php echo esc_attr($appearance['chat_box_width'] ?? '350'); ?>"
                               min="300"
                               max="800">
                        <span class="description">px</span>
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[chat_box_height]">Chat Box Height</label>
                    </th>
                    <td>
                        <input type="number" 
                               id="ai_chatbot_appearance_chat_box_height" 
                               name="ai_chatbot_appearance[chat_box_height]" 
                               value="<?php echo esc_attr($appearance['chat_box_height'] ?? '500'); ?>"
                               min="400"
                               max="800">
                        <span class="description">px</span>
                    </td>
                </tr>

                <tr>
                    <th scope="row">Font Sizes</th>
                    <td>
                        <label>
                            User Messages:
                            <input type="number" 
                                   name="ai_chatbot_appearance[user_message_font_size]" 
                                   value="<?php echo esc_attr($appearance['user_message_font_size'] ?? '14'); ?>"
                                   min="12"
                                   max="20">
                            px
                        </label>
                        <br>
                        <label>
                            Bot Messages:
                            <input type="number" 
                                   name="ai_chatbot_appearance[bot_message_font_size]" 
                                   value="<?php echo esc_attr($appearance['bot_message_font_size'] ?? '14'); ?>"
                                   min="12"
                                   max="20">
                            px
                        </label>
                        <br>
                        <label>
                            Header Text:
                            <input type="number" 
                                   name="ai_chatbot_appearance[header_font_size]" 
                                   value="<?php echo esc_attr($appearance['header_font_size'] ?? '16'); ?>"
                                   min="14"
                                   max="24">
                            px
                        </label>
                    </td>
                </tr>

                <tr>
                    <th scope="row">
                        <label for="ai_chatbot_appearance[bot_message_bg]">Bot Message Background</label>
                    </th>
                    <td>
                        <input type="text" 
                               id="ai_chatbot_appearance_bot_message_bg" 
                               name="ai_chatbot_appearance[bot_message_bg]" 
                               value="<?php echo esc_attr($appearance['bot_message_bg'] ?? '#f1f1f1'); ?>"
                               class="color-picker">
                    </td>
                </tr>
            </table>
        </div>
        
        <?php submit_button(); ?>
    </form>
</div>

<style>
.tab-content {
    display: none;
    padding: 20px 0;
}

.tab-content.active {
    display: block;
}

.nav-tab-wrapper {
    margin-bottom: 20px;
}

.nav-tab {
    cursor: pointer;
}

.nav-tab-active {
    background: #fff;
    border-bottom: 1px solid #fff;
    margin-bottom: -1px;
}
</style>