<?php
class AI_Business_Chatbot_Conversation {
    private $api_url = 'https://quickworkspace.ai/api/ai/conversations';

    public function create_conversation() {
        $api_key = get_option('ai_chatbot_api_key');
        $workspace_id = get_option('ai_chatbot_workspace_id');

        if (!$api_key || !$workspace_id) {
            return array(
                'success' => false,
                'message' => 'API configuration missing'
            );
        }

        $response = wp_remote_post($this->api_url, array(
            'headers' => array(
                'X-Workspace-Id' => $workspace_id,
                'X-Api-Key' => $api_key,
                'Accept' => 'application/json'
            )
        ));

        if (is_wp_error($response)) {
            return array(
                'success' => false,
                'message' => $response->get_error_message()
            );
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);

        if (empty($body['id'])) {
            return array(
                'success' => false,
                'message' => 'Invalid API response'
            );
        }

        // Save conversation to database
        global $wpdb;
        $wpdb->insert(
            $wpdb->prefix . 'ai_chatbot_conversations',
            array(
                'conversation_id' => $body['id'],
                'user_id' => get_current_user_id(),
                'created_at' => current_time('mysql'),
                'title' => $body['title']
            ),
            array('%s', '%d', '%s', '%s')
        );

        return array(
            'success' => true,
            'conversation_id' => $body['id']
        );
    }
}