<?php
class AI_Business_Chatbot_DB {
    private $table_name;

    public function __construct() {
        global $wpdb;
        $this->table_name = $wpdb->prefix . 'ai_chatbot_settings';
    }

    public function create_tables() {
        global $wpdb;
        $charset_collate = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE IF NOT EXISTS $this->table_name (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            api_key varchar(255) NOT NULL,
            workspace_id varchar(255) NOT NULL,
            workspace_name varchar(255) NOT NULL,
            total_credit_count float NOT NULL,
            usage_count float NOT NULL,
            credit_percentage varchar(10) NOT NULL,
            plan_title varchar(255) NOT NULL,
            plan_price float NOT NULL,
            plan_billing_cycle varchar(50) NOT NULL,
            available_models longtext NOT NULL,
            last_updated datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY  (id)
        ) $charset_collate;";

        $sql_conversations = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}ai_chatbot_conversations (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            conversation_id varchar(255) NOT NULL,
            user_id bigint(20) NOT NULL,
            created_at datetime DEFAULT CURRENT_TIMESTAMP,
            status varchar(50) DEFAULT 'active',
            title varchar(255),
            PRIMARY KEY  (id)
        ) $charset_collate;";

        $sql_messages = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}ai_chatbot_messages (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            conversation_id varchar(255) NOT NULL,
            message_id varchar(255) NOT NULL,
            parent_id varchar(255) DEFAULT NULL,
            role varchar(50) NOT NULL,
            content text NOT NULL,
            cost float DEFAULT 0,
            created_at datetime DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY  (id),
            KEY conversation_id (conversation_id),
            KEY message_id (message_id)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
        dbDelta($sql_conversations);
        dbDelta($sql_messages);
    }

    public function save_account_data($data) {
        global $wpdb;
        
        $existing = $wpdb->get_row("SELECT id FROM $this->table_name LIMIT 1");
        
        $save_data = array(
            'api_key' => $data['api_key'],
            'workspace_id' => $data['workspace_id'],
            'workspace_name' => $data['workspace_name'],
            'total_credit_count' => $data['total_credit_count'],
            'usage_count' => $data['usage_count'],
            'credit_percentage' => $data['credit_percentage'],
            'plan_title' => $data['plan_title'],
            'plan_price' => $data['plan_price'],
            'plan_billing_cycle' => $data['plan_billing_cycle'],
            'available_models' => json_encode($data['available_models']),
            'last_updated' => current_time('mysql')
        );

        if ($existing) {
            $wpdb->update(
                $this->table_name,
                $save_data,
                array('id' => $existing->id)
            );
        } else {
            $wpdb->insert($this->table_name, $save_data);
        }
    }
}