<?php
class AI_Business_Chatbot_Loader {
    protected $actions;
    protected $filters;
    private static $instance = null;

    public function __construct() {
        $this->actions = array();
        $this->filters = array();
        
        $this->load_dependencies();
        $this->define_admin_hooks();
        $this->define_public_hooks();
    }

    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function load_dependencies() {
        require_once AI_BUSINESS_CHATBOT_PLUGIN_DIR . 'includes/class-api.php';
        require_once AI_BUSINESS_CHATBOT_PLUGIN_DIR . 'includes/class-database.php';
        require_once AI_BUSINESS_CHATBOT_PLUGIN_DIR . 'admin/class-admin.php';
        require_once AI_BUSINESS_CHATBOT_PLUGIN_DIR . 'public/class-public.php';
    }

    private function define_admin_hooks() {
        $plugin_admin = new AI_Business_Chatbot_Admin();
        
        add_action('admin_enqueue_scripts', array($plugin_admin, 'enqueue_styles'));
        add_action('admin_enqueue_scripts', array($plugin_admin, 'enqueue_scripts'));
        add_action('admin_menu', array($plugin_admin, 'add_plugin_admin_menu'));
        add_action('admin_init', array($plugin_admin, 'register_settings'));
    }

    private function define_public_hooks() {
        $plugin_public = new AI_Business_Chatbot_Public();
        
        add_action('wp_enqueue_scripts', array($plugin_public, 'enqueue_styles'));
        add_action('wp_enqueue_scripts', array($plugin_public, 'enqueue_scripts'));
        add_action('wp_footer', array($plugin_public, 'render_chat_widget'));
        add_action('wp_ajax_create_conversation', array($this, 'handle_create_conversation'));
        add_action('wp_ajax_nopriv_create_conversation', array($this, 'handle_create_conversation'));
        add_action('wp_ajax_send_message', array($this, 'handle_send_message'));
        add_action('wp_ajax_nopriv_send_message', array($this, 'handle_send_message'));
    }

    public function handle_create_conversation() {
        check_ajax_referer('ai_chatbot_public_nonce', 'nonce');
        
        require_once AI_BUSINESS_CHATBOT_PLUGIN_DIR . 'includes/class-conversation.php';
        $conversation = new AI_Business_Chatbot_Conversation();
        $result = $conversation->create_conversation();
        
        wp_send_json($result);
    }

    public function handle_send_message() {
        check_ajax_referer('ai_chatbot_public_nonce', 'nonce');
        
        $conversation_id = sanitize_text_field($_POST['conversation_id']);
        $message = sanitize_textarea_field($_POST['message']);
        $parent_id = isset($_POST['parent_id']) ? sanitize_text_field($_POST['parent_id']) : null;

        require_once AI_BUSINESS_CHATBOT_PLUGIN_DIR . 'includes/class-chatting.php';
        $chat = new AI_Business_Chatbot_Chatting();
        $result = $chat->send_message($conversation_id, $message, $parent_id);
        
        wp_send_json($result);
    }
}