<?php
class AI_Business_Chatbot_Public {
    public function __construct() {
        // Constructor
    }

    public function enqueue_styles() {
        wp_enqueue_style(
            'ai-business-chatbot-public',
            AI_BUSINESS_CHATBOT_PLUGIN_URL . 'public/css/public.css',
            array(),
            AI_BUSINESS_CHATBOT_VERSION
        );

        // Add custom CSS variables
        $appearance = get_option('ai_chatbot_appearance', array());
        $custom_css = "
            :root {
                --chat-color: {$appearance['chat_color']};
                --messages-color: {$appearance['messages_color']};
                --messages-border-radius: {$appearance['messages_border_radius']}px;
                --chat-box-border-radius: {$appearance['chat_box_border_radius']}px;
            }
            {$appearance['custom_css']}
        ";
        wp_add_inline_style('ai-business-chatbot-public', $custom_css);
    }

    public function enqueue_scripts() {
        // Add marked.js for markdown parsing
        wp_enqueue_script(
            'marked',
            'https://cdn.jsdelivr.net/npm/marked/marked.min.js',
            array(),
            '4.0.0',
            true
        );

        wp_enqueue_script(
            'ai-business-chatbot-public',
            AI_BUSINESS_CHATBOT_PLUGIN_URL . 'public/js/public.js',
            array('jquery', 'marked'),
            AI_BUSINESS_CHATBOT_VERSION,
            true
        );

        wp_localize_script('ai-business-chatbot-public', 'aiChatbotPublic', array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('ai_chatbot_public_nonce')
        ));
    }

    public function render_chat_widget() {
        if (get_option('ai_chatbot_display_mode') === 'entire_site') {
            $chat_title = get_option('ai_chatbot_chat_title', 'Chat Support');
            ?>
            <div class="ai-chatbot-widget">
                <div class="ai-chatbot-icon">
                    <svg viewBox="0 0 24 24">
                        <path d="M20 2H4c-1.1 0-2 .9-2 2v18l4-4h14c1.1 0 2-.9 2-2V4c0-1.1-.9-2-2-2zm0 14H6l-2 2V4h16v12z"/>
                    </svg>
                </div>
                <div class="ai-chatbot-container">
                    <div class="ai-chatbot-header">
                        <h3><?php echo esc_html($chat_title); ?></h3>
                    </div>
                    <div class="ai-chatbot-start-screen">
                        <button class="ai-chatbot-start-chat">Start New Chat</button>
                    </div>
                    <div class="ai-chatbot-messages" style="display: none;">
                        <!-- Messages will be inserted here -->
                    </div>
                    <div class="ai-chatbot-input" style="display: none;">
                        <form id="ai-chatbot-form">
                            <input type="text" placeholder="Type your message..." required>
                            <button type="submit">Send</button>
                        </form>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}