(function($) {
    'use strict';
    // Public scripts will go here

    $(document).ready(function() {
        const $chatIcon = $('.ai-chatbot-icon');
        const $chatContainer = $('.ai-chatbot-container');
        const $startScreen = $('.ai-chatbot-start-screen');
        const $chatMessages = $('.ai-chatbot-messages');
        const $chatInput = $('.ai-chatbot-input');
        const $startChatBtn = $('.ai-chatbot-start-chat');
        const $chatForm = $('#ai-chatbot-form');
        let conversationId = localStorage.getItem('ai_chatbot_conversation_id');
        let lastParentId = localStorage.getItem('ai_chatbot_last_parent_id_' + conversationId);

        // Toggle chat container
        $chatIcon.on('click', function() {
            $chatContainer.toggleClass('active');
        });

        // Start new chat
        $startChatBtn.on('click', function() {
            $.ajax({
                url: aiChatbotPublic.ajaxurl,
                type: 'POST',
                data: {
                    action: 'create_conversation',
                    nonce: aiChatbotPublic.nonce
                },
                success: function(response) {
                    if (response.success) {
                        conversationId = response.conversation_id;
                        localStorage.setItem('ai_chatbot_conversation_id', conversationId);
                        $startScreen.hide();
                        $chatMessages.show();
                        $chatInput.show();
                    } else {
                        alert('Failed to start chat. Please try again.');
                    }
                }
            });
        });

        // Handle message submission
        $chatForm.on('submit', function(e) {
            e.preventDefault();
            
            const $input = $(this).find('input');
            const message = $input.val();
            
            if (message.trim() && conversationId) {
                appendMessage('user', message);
                $input.val('');
                
                $.ajax({
                    url: aiChatbotPublic.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'send_message',
                        nonce: aiChatbotPublic.nonce,
                        conversation_id: conversationId,
                        message: message,
                        parent_id: lastParentId
                    },
                    success: function(response) {
                        if (response.success) {
                            appendMessage('bot', response.content);
                            lastParentId = response.message_id;
                            localStorage.setItem('ai_chatbot_last_parent_id_' + conversationId, lastParentId);
                        } else {
                            appendMessage('error', 'Failed to send message. Please try again.');
                        }
                    }
                });
            }
        });

        function appendMessage(type, content) {
            if (type === 'bot') {
                // First show typing indicator
                const typingHtml = `
                    <div class="typing-indicator">
                        <span></span>
                        <span></span>
                        <span></span>
                    </div>
                `;
                $chatMessages.append(typingHtml);
                $chatMessages.scrollTop($chatMessages[0].scrollHeight);

                // Split content into characters
                const chars = content.split('');
                let messageHtml = `
                    <div class="ai-chatbot-message ${type}">
                        <div class="message-content"></div>
                    </div>
                `;
                
                // Remove typing indicator and append message container
                setTimeout(() => {
                    $('.typing-indicator').remove();
                    $chatMessages.append(messageHtml);
                    const $messageContent = $chatMessages.find('.ai-chatbot-message:last-child .message-content');
                    
                    // Type out the message with faster speed
                    let i = 0;
                    const typeChar = () => {
                        if (i < chars.length) {
                            $messageContent.append(chars[i]);
                            $chatMessages.scrollTop($chatMessages[0].scrollHeight);
                            i++;
                            setTimeout(typeChar, Math.random() * 10 + 5); // Faster random delay between 5-15ms
                        }
                    };
                    typeChar();
                }, 500); // Reduced typing indicator time to 500ms
            } else {
                // User messages appear immediately with slide-up animation
                const messageHtml = `
                    <div class="ai-chatbot-message ${type}">
                        <div class="message-content">
                            ${content}
                        </div>
                    </div>
                `;
                $chatMessages.append(messageHtml);
                $chatMessages.scrollTop($chatMessages[0].scrollHeight);
            }
        }

        function sendMessage(message) {
            const $input = $('#ai-chatbot-form input');
            $input.prop('disabled', true);
            
            appendMessage('user', message);

            $.ajax({
                url: aiChatbotPublic.ajaxurl,
                type: 'POST',
                data: {
                    action: 'ai_chatbot_send_message',
                    nonce: aiChatbotPublic.nonce,
                    message: message,
                    conversation_id: conversationId,
                    parent_id: lastParentId
                },
                success: function(response) {
                    if (response.success) {
                        appendMessage('bot', response.content);
                        lastParentId = response.message_id;
                    } else {
                        appendMessage('error', response.message || 'An error occurred');
                    }
                },
                error: function() {
                    appendMessage('error', 'Failed to send message');
                },
                complete: function() {
                    $input.prop('disabled', false);
                    $input.val('').focus();
                }
            });
        }
    });
})(jQuery); 